==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2beta1HorizontalPodAutoscalerFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V2beta1HorizontalPodAutoscalerFluent<A extends V2beta1HorizontalPodAutoscalerFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> withNewMetadata();
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> editMetadata();
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> editOrNewMetadata();
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1HorizontalPodAutoscalerSpec getSpec();
    public V2beta1HorizontalPodAutoscalerSpec buildSpec();
    public A withSpec(V2beta1HorizontalPodAutoscalerSpec spec);
    public Boolean hasSpec();
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> withNewSpec();
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> withNewSpecLike(V2beta1HorizontalPodAutoscalerSpec item);
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> editSpec();
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> editOrNewSpec();
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> editOrNewSpecLike(V2beta1HorizontalPodAutoscalerSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1HorizontalPodAutoscalerStatus getStatus();
    public V2beta1HorizontalPodAutoscalerStatus buildStatus();
    public A withStatus(V2beta1HorizontalPodAutoscalerStatus status);
    public Boolean hasStatus();
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> withNewStatus();
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> withNewStatusLike(V2beta1HorizontalPodAutoscalerStatus item);
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> editStatus();
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> editOrNewStatus();
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> editOrNewStatusLike(V2beta1HorizontalPodAutoscalerStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V2beta1HorizontalPodAutoscalerFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1HorizontalPodAutoscalerSpecFluent<V2beta1HorizontalPodAutoscalerFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1HorizontalPodAutoscalerStatusFluent<V2beta1HorizontalPodAutoscalerFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta1HorizontalPodAutoscalerFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V2beta1HorizontalPodAutoscalerFluent<A extends V2beta1HorizontalPodAutoscalerFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> withNewMetadata();
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> editMetadata();
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> editOrNewMetadata();
    public V2beta1HorizontalPodAutoscalerFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1HorizontalPodAutoscalerSpec getSpec();
    public V2beta1HorizontalPodAutoscalerSpec buildSpec();
    public A withSpec(V2beta1HorizontalPodAutoscalerSpec spec);
    public Boolean hasSpec();
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> withNewSpec();
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> withNewSpecLike(V2beta1HorizontalPodAutoscalerSpec item);
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> editSpec();
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> editOrNewSpec();
    public V2beta1HorizontalPodAutoscalerFluent.SpecNested<A> editOrNewSpecLike(V2beta1HorizontalPodAutoscalerSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1HorizontalPodAutoscalerStatus getStatus();
    public V2beta1HorizontalPodAutoscalerStatus buildStatus();
    public A withStatus(V2beta1HorizontalPodAutoscalerStatus status);
    public Boolean hasStatus();
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> withNewStatus();
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> withNewStatusLike(V2beta1HorizontalPodAutoscalerStatus item);
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> editStatus();
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> editOrNewStatus();
    public V2beta1HorizontalPodAutoscalerFluent.StatusNested<A> editOrNewStatusLike(V2beta1HorizontalPodAutoscalerStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V2beta1HorizontalPodAutoscalerFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1HorizontalPodAutoscalerSpecFluent<V2beta1HorizontalPodAutoscalerFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1HorizontalPodAutoscalerStatusFluent<V2beta1HorizontalPodAutoscalerFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
